package ub.cse.algo;
import java.util.ArrayList;

/**
 * Class for running the grader. Will take in a command line argument specifying
 * the number of testcases to run.
 */
public class Driver {

    private static String inputFilename;

    private static void printResult(ArrayList<Pair<Literals, Literals>> result){

        StringBuilder builder = new StringBuilder();
        boolean isFirstClause = true;
        builder.append("[");

        for (Pair<Literals, Literals> clause: result){

            if (!isFirstClause){
                builder.append(", ");
            }
            else{
                isFirstClause = false;
            }

            builder.append("([");
            ArrayList<Pair<Integer, Integer>> positive = clause.getFirst();
            ArrayList<Pair<Integer, Integer>> negative = clause.getSecond();
            boolean isFirst = true;

            for (Pair<Integer, Integer> literal: positive){
                if (!isFirst){
                    builder.append(", ");
                }
                else{
                    isFirst = false;
                }
                builder.append("(");
                builder.append(literal.getFirst());
                builder.append(", ");
                builder.append(literal.getSecond());
                builder.append(")");
            }

            builder.append("], ");
            builder.append("[");
            isFirst = true;

            for (Pair<Integer, Integer> literal: negative){
                if (!isFirst){
                    builder.append(", ");
                }
                else{
                    isFirst = false;
                }
                builder.append("(");
                builder.append(literal.getFirst());
                builder.append(", ");
                builder.append(literal.getSecond());
                builder.append(")");
            }
            builder.append("])");
        }
        builder.append("]");
        System.out.println(builder);
    }

    public static void main(String[] args) {
        if (args.length != 1) {
            System.out.println("Please provide the testcase filepath as a command line argument");
        }
        inputFilename = args[0];

        Graph graph = new HW10Utility().readFile(inputFilename);

        Integer k = graph.getK();

        Solution student = new Solution(k, graph);
        ArrayList<Pair<Literals, Literals>> studentSolution = student.outputClauses();

        System.out.println("Your solution:");
        System.out.println("=======================================================================================================");
        if(studentSolution != null){
            printResult(studentSolution);
            Helpers helper = new Helpers();
            helper.writeCnf(graph, helper.convertFormat(studentSolution, k));
            System.out.println("Please submit the formula.txt file generated in the current directory to Autolab to run the solver on your SAT formula");
        } else {
            System.out.println("[]");
        }
        System.out.println("=======================================================================================================");
    }
}
